@@ -19,7 +19,7 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 
-/* $Id: client.c,v 1.1.1.1 2005/04/09 22:51:37 evertonm Exp $ */
+/* $Id: client.c,v 1.6 2005/04/19 03:40:33 evertonm Exp $ */
 
 #include <stdio.h>
 #include <sys/types.h>
@@ -59,14 +59,14 @@ static void schedule_stat_interval(int sd)
 static void *on_tcp_read(oop_source *src, int sd,
                          oop_event event, void *user)
 {
-  char buf[nepim_global.read_size];
+  char buf[nepim_global.tcp_read_size];
   int rd;
   nepim_pipe_t *pipe = user;
 
   assert(event == OOP_READ);
   assert(sd == pipe->sd);
 
-  rd = read(sd, buf, nepim_global.read_size);
+  rd = read(sd, buf, nepim_global.tcp_read_size);
   if (rd < 1) {
     switch (errno) {
     case EINTR:
@@ -89,6 +89,8 @@ static void *on_tcp_read(oop_source *src, int sd,
 
   pipe->byte_total_recv += rd;
   pipe->byte_interval_recv += rd;
+  ++pipe->total_reads;
+  ++pipe->interval_reads;
 
   return OOP_CONTINUE;
 }
@@ -96,7 +98,7 @@ static void *on_tcp_read(oop_source *src, int sd,
 static void *on_tcp_write(oop_source *src, int sd,
                           oop_event event, void *user)
 {
-  char buf[nepim_global.write_size];
+  char buf[nepim_global.tcp_write_size];
   int wr;
   nepim_pipe_t *pipe = user;
 
@@ -104,7 +106,7 @@ static void *on_tcp_write(oop_source *src, int sd,
   assert(sd == pipe->sd);
   assert(pipe->max_bit_rate < 1);
 
-  wr = write(sd, buf, nepim_global.write_size);
+  wr = write(sd, buf, nepim_global.tcp_write_size);
   if (wr < 1) {
     switch (errno) {
     case EINTR:
@@ -130,6 +132,8 @@ static void *on_tcp_write(oop_source *src, int sd,
 
   pipe->byte_total_sent += wr;
   pipe->byte_interval_sent += wr;
+  ++pipe->total_writes;
+  ++pipe->interval_writes;
 
   return OOP_CONTINUE;
 }
@@ -137,7 +141,7 @@ static void *on_tcp_write(oop_source *src, int sd,
 static void *on_tcp_rate_write(oop_source *src, int sd,
 			       oop_event event, void *user)
 {
-  char buf[nepim_global.write_size];
+  char buf[nepim_global.tcp_write_size];
   int wr;
   nepim_pipe_t *pipe = user;
   int to_write;
@@ -146,7 +150,7 @@ static void *on_tcp_rate_write(oop_source *src, int sd,
   assert(sd == pipe->sd);
   assert(pipe->max_bit_rate > 0);
 
-  to_write = NEPIM_MIN(pipe->rate_remaining, nepim_global.write_size);
+  to_write = NEPIM_MIN(pipe->rate_remaining, nepim_global.tcp_write_size);
 
   wr = write(sd, buf, to_write);
   if (wr < 1) {
@@ -175,6 +179,8 @@ static void *on_tcp_rate_write(oop_source *src, int sd,
   pipe->byte_total_sent += wr;
   pipe->byte_interval_sent += wr;
   pipe->rate_remaining -= wr;
+  ++pipe->total_writes;
+  ++pipe->interval_writes;
 
 #if 0
   fprintf(stderr, 
@@ -249,15 +255,19 @@ static void *on_tcp_duration(oop_source *src, struct timeval tv, void *user)
 
   assert(timercmp(&tv, &pipe->tv_duration, ==));
 
-  nepim_dump_stat(stdout, "total", pipe->sd, 
+  nepim_dump_stat(stdout, NEPIM_LABEL_TOTAL, pipe->sd, 
 		  pipe->byte_total_recv,
 		  pipe->byte_total_sent,
 		  pipe->test_duration,
 		  pipe->tv_start.tv_sec,
-		  pipe->test_duration);
+		  pipe->test_duration,
+		  pipe->total_reads,
+		  pipe->total_writes);
 
   pipe->byte_total_recv = 0;
   pipe->byte_total_sent = 0;
+  pipe->total_reads     = 0;
+  pipe->total_writes    = 0;
 
   tcp_pipe_stop(pipe->sd);
   close(pipe->sd);
@@ -271,22 +281,26 @@ static void *on_tcp_interval(oop_source *src, struct timeval tv, void *user)
 
   assert(timercmp(&tv, &pipe->tv_interval, ==));
 
-  nepim_dump_stat(stdout, "partial", pipe->sd, 
+  nepim_dump_stat(stdout, NEPIM_LABEL_PARTIAL, pipe->sd, 
 		  pipe->byte_interval_recv,
 		  pipe->byte_interval_sent,
 		  pipe->stat_interval,
 		  pipe->tv_start.tv_sec,
-		  pipe->test_duration);
+		  pipe->test_duration,
+		  pipe->interval_reads,
+		  pipe->interval_writes);
 
   pipe->byte_interval_recv = 0;
   pipe->byte_interval_sent = 0;
+  pipe->interval_reads     = 0;
+  pipe->interval_writes    = 0;
 
   schedule_stat_interval(pipe->sd);
 
   return OOP_CONTINUE;
 }
 
-static void greet(int sd)
+static int greet(int sd)
 {
   char buf[1024];
   int pr;
@@ -307,7 +321,10 @@ static void greet(int sd)
   fprintf(stderr, "%d: sending: %s", sd, buf);
 
   wr = write(sd, buf, pr);
-  assert(wr == pr);
+  if (wr != pr)
+    return -1;
+
+  return 0;
 }
 
 static void tcp_pipe_start(int sd)
@@ -333,6 +350,7 @@ static void tcp_pipe_start(int sd)
     }
   }
 
+
   {
     int result = gettimeofday(&pipe->tv_start, 0);
     assert(!result);
@@ -415,13 +433,13 @@ static void spawn_one_tcp_client()
 	    "TCP socket trying %s,%d\n",
 	    nepim_global.hostname, nepim_global.port);
 
-    sd = connect_client_socket(ai->ai_addr, ai->ai_addrlen,
-			       ai->ai_family, ai->ai_socktype, 
-			       ai->ai_protocol, nepim_global.port);
+    sd = nepim_connect_client_socket(ai->ai_addr, ai->ai_addrlen,
+				     ai->ai_family, ai->ai_socktype, 
+				     ai->ai_protocol, nepim_global.port);
     if (sd < 0) {
       fprintf(stderr, 
-	      "could not connect TCP socket to %s,%d\n",
-	      nepim_global.hostname, nepim_global.port);
+	      "could not connect TCP socket to %s,%d: %d\n",
+	      nepim_global.hostname, nepim_global.port, sd);
       continue;
     }
 
@@ -432,21 +450,12 @@ static void spawn_one_tcp_client()
 	    ai->ai_addrlen, ai->ai_family, 
 	    ai->ai_socktype, ai->ai_protocol);
 
-    greet(sd);
-
-    fprintf(stderr, 
-	    "%d: greetings sent to %s,%d\n",
-	    sd, nepim_global.hostname, nepim_global.port);
-
-    nepim_pipe_set_add(&pipes, sd, 
-		       1,
+    nepim_pipe_set_add(&pipes, sd, 1,
 		       nepim_global.bit_rate, 
 		       nepim_global.stat_interval,
 		       nepim_global.test_duration,
 		       nepim_global.write_delay);
 
-    tcp_pipe_start(sd);
-
     break;
   }
 
@@ -457,19 +466,43 @@ static void spawn_tcp_clients()
 {
   int i;
 
+  /* create sockets */
   for (i = 0; i < nepim_global.pipes; ++i)
     spawn_one_tcp_client();
+
+  /* activate sockets */
+  for (i = 0; i < pipes.capacity; ++i)
+    if (nepim_pipe_set_get(&pipes, i)) {
+
+      if (greet(i)) {
+	fprintf(stderr,
+		"%d: could not greet %s,%d\n",
+		i, nepim_global.hostname, nepim_global.port);
+
+	nepim_pipe_set_del(&pipes, i);
+	close(i);
+
+	continue;
+      }
+
+      fprintf(stderr, 
+	      "%d: greetings sent to %s,%d\n",
+	      i, nepim_global.hostname, nepim_global.port);
+
+      tcp_pipe_start(i);
+    }
 }
 
+void nepim_udp_clients();
+
 void nepim_client_run()
 {
   void *result;
 
   nepim_pipe_set_init(&pipes);
 
-  if (nepim_global.udp_mode) {
-    fprintf(stderr, "FIXME: udp_mode\n");
-  }
+  if (nepim_global.udp_mode)
+    nepim_udp_clients();
   else
     spawn_tcp_clients();
 
