@@ -19,7 +19,7 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 
-/* $Id: common.c,v 1.4 2005/04/19 03:40:33 evertonm Exp $ */
+/* $Id: common.c,v 1.6 2005/04/19 21:44:50 evertonm Exp $ */
 
 #include <stdio.h>
 #include <assert.h>
@@ -34,7 +34,7 @@ const char * const NEPIM_LABEL_TOTAL_BROKEN = "sum(broken)";
 
 const char *nepim_version()
 {
-  return "0.5";
+  return "0.6";
 }
 
 void nepim_dump_stat(FILE *out, const char *label, int sd, 
@@ -44,8 +44,8 @@ void nepim_dump_stat(FILE *out, const char *label, int sd,
 {
   float kbps_recv = bytes_recv / (interval * 125); /* 8/1000 = 1/125 */
   float kbps_sent = bytes_sent / (interval * 125); /* 8/1000 = 1/125 */
-  float read_rate = reads / (interval * 1000);
-  float write_rate = writes / (interval * 1000);
+  float read_rate = reads / interval;
+  float write_rate = writes / interval;
   struct timeval now;
   int result;
       
@@ -53,7 +53,7 @@ void nepim_dump_stat(FILE *out, const char *label, int sd,
   assert(!result);
 
   fprintf(out,
-	  "%d: %s %ld/%ld kbps_in=%.2f kbps_out=%.2f rcv/s=%.4f snd/s=%.4f\n", 
+	  "%d: %s %ld/%ld kbps_in=%.2f kbps_out=%.2f rcv/s=%.2f snd/s=%.2f\n", 
 	  sd,
 	  label,
 	  now.tv_sec - sec_start,
