@@ -36,8 +36,10 @@ struct nepim_global_t {
   long long   bit_rate;
   int         stat_interval;
   int         test_duration;
-  int         write_size;
-  int         read_size;
+  int         tcp_write_size;
+  int         tcp_read_size;
+  int         udp_write_size;
+  int         udp_read_size;
   int         port;
   int         no_inet6;
   suseconds_t write_delay;
