@@ -27,19 +27,27 @@ Boston, MA 02111-1307, USA.
 
 int nepim_socket_nonblock(int sd);
 int nepim_socket_block(int sd);
+int nepim_socket_opt(int sd);
+int nepim_socket_tcp_opt(int sd);
 
-int create_listener_socket(struct sockaddr *addr,
-			   int addr_len,
-                           int family,
-                           int type,
-                           int protocol,
-			   int port);
-int connect_client_socket(struct sockaddr *addr,
-			  int addr_len,
-			  int family,
-			  int type,
-			  int protocol,
-			  int port);
+int nepim_create_socket(struct sockaddr *addr,
+			int addr_len,
+			int family,
+			int type,
+			int protocol,
+			int port);
+int nepim_create_listener_socket(struct sockaddr *addr,
+				 int addr_len,
+				 int family,
+				 int type,
+				 int protocol,
+				 int port);
+int nepim_connect_client_socket(struct sockaddr *addr,
+				int addr_len,
+				int family,
+				int type,
+				int protocol,
+				int port);
 
 #endif /* NEPIM_SOCK_H */
 
